pub fn upsert(c: &mut Connection, row: &ProgressRow) -> Result<()>Expand description
Insert or update the progress row for a book. last_read_at is always
refreshed to CURRENT_TIMESTAMP.
pub fn upsert(c: &mut Connection, row: &ProgressRow) -> Result<()>Insert or update the progress row for a book. last_read_at is always
refreshed to CURRENT_TIMESTAMP.