pub fn init(log_dir: &Path) -> Result<WorkerGuard>Expand description
Initialise tracing with daily-rotated file logs at log_dir.
Returns a guard that must live for the duration of the program.
pub fn init(log_dir: &Path) -> Result<WorkerGuard>Initialise tracing with daily-rotated file logs at log_dir.
Returns a guard that must live for the duration of the program.